@@ -87,4 +87,5 @@ class Utils:
         return self
     
     def open_docs(self):
-        webopen(f"file://{inspect.getfile(pyBase).replace('pyBase.py','Docs\\index.html').replace('\\','/')}")
+        p = inspect.getfile(pyBase).replace('pyBase.py','Docs/index.html').replace('\\','/')
+        webopen(f"file://{p}")
